@@ -78,8 +78,8 @@
         <translation>Некорректная ссылка на псевдоним. Не удалось найти id «%1»</translation>
     </message>
     <message>
-        <source>Invalid alias location</source>
-        <translation>Некорректное размещение псевдонима</translation>
+        <source>Invalid alias target location: %1</source>
+        <translation>Некорректное размещение цели псевдонима: %1</translation>
     </message>
 </context>
 <context>
@@ -334,6 +334,10 @@
 </context>
 <context>
     <name>QQmlEnumTypeResolver</name>
+    <message>
+        <source>Invalid property assignment: Enum value &quot;%1&quot; cannot start with a lowercase letter</source>
+        <translation>Некорректное присваивание свойства: Значение перечисления «%1» не может начинаться с маленькой буквы</translation>
+    </message>
     <message>
         <source>Invalid property assignment: &quot;%1&quot; is a read-only property</source>
         <translation>Некорректное присваивание свойства: «%1» свойство только для чтения</translation>
@@ -544,6 +548,21 @@
         <translation>Нельзя создавать сложный Singleton-тип %1</translation>
     </message>
 </context>
+<context>
+    <name>QQmlObjectModel</name>
+    <message>
+        <source>insert: index %1 out of range</source>
+        <translation>insert: индекс %1 вне диапазона</translation>
+    </message>
+    <message>
+        <source>move: out of range</source>
+        <translation>move: индекс вне диапазона</translation>
+    </message>
+    <message>
+        <source>remove: indices [%1 - %2] out of range [0 - %3]</source>
+        <translation>remove: индексы [%1 - %2] вне диапазона [0 - %3]</translation>
+    </message>
+</context>
 <context>
     <name>QQmlParser</name>
     <message>
@@ -1093,6 +1112,17 @@
         <translation>Drag доступна только через прикреплённые свойства</translation>
     </message>
 </context>
+<context>
+    <name>QQuickEnterKeyAttached</name>
+    <message>
+        <source>EnterKey attached property only works with Items</source>
+        <translation>Подключённое свойство EnterKey работает только с элементами</translation>
+    </message>
+    <message>
+        <source>EnterKey is only available via attached properties</source>
+        <translation>EnterKey доступно только через подключённые свойства</translation>
+    </message>
+</context>
 <context>
     <name>QQuickFlipable</name>
     <message>
@@ -1234,10 +1264,6 @@
         <source>Cannot open: %1</source>
         <translation>Не удалось открыть: %1</translation>
     </message>
-    <message>
-        <source>Invalid image data: %1</source>
-        <translation>Некорректные данные изображения: %1</translation>
-    </message>
 </context>
 <context>
     <name>QQuickPropertyAnimation</name>
@@ -1379,6 +1405,17 @@ Install a driver providing OpenGL 2.0 or higher, or, if this is not possible, ma
         <translation>Неверно указано назначение сигнала</translation>
     </message>
 </context>
+<context>
+    <name>SignalTransition</name>
+    <message>
+        <source>Cannot assign to non-existent property &quot;%1&quot;</source>
+        <translation>Невозможно назначить несуществующему свойству «%1»</translation>
+    </message>
+    <message>
+        <source>SignalTransition: script expected</source>
+        <translation>SignalTransition: ожидается сценарий</translation>
+    </message>
+</context>
 <context>
     <name>qmlRegisterType</name>
     <message>
